
# This file was automatically generated by Dist::Zilla::Plugin::Alien v0.010.
use strict;
use warnings;

use Module::Build 0.3601;
use lib qw{inc}; use Alien::pdf2json::ModuleBuild;

my %module_build_args = (
  "alien_name" => "pdf2json",
  "alien_repository" => {
    "host" => "",
    "location" => "inc",
    "pattern" => "^pdf2json-([\\d\\.]+)\\.tar\\.gz\$",
    "protocol" => "local"
  },
  "build_requires" => {},
  "configure_requires" => {
    "Alien::Base" => "0.002",
    "ExtUtils::MakeMaker" => "6.30",
    "File::ShareDir" => "1.03",
    "Path::Class" => "0.013"
  },
  "dist_abstract" => "Alien package for the pdf2json PDF extraction library",
  "dist_author" => [
    "Zakariyya Mughal <zmughal\@cpan.org>"
  ],
  "dist_name" => "Alien-pdf2json",
  "dist_version" => "0.001",
  "license" => "perl",
  "module_name" => "Alien::pdf2json",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Alien::Base" => "0.002",
    "File::ShareDir" => "1.03",
    "File::Spec" => 0,
    "Path::Class" => "0.013",
    "parent" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/pdf2json"
  ],
  "test_requires" => {
    "IPC::Open3" => 0,
    "Symbol" => 0,
    "Test::More" => 0
  }
);


my %fallback_build_requires = (
  "IPC::Open3" => 0,
  "Symbol" => 0,
  "Test::More" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Alien::pdf2json::ModuleBuild->new(%module_build_args);

$build->create_build_script;
